;Filename: SpiCfg.s
;Part    : ADuC703x.
;Created : 14/04/2006
;Author  : Patrick Noonan (Analog Device Inc.)
;This file is in beta sampling.

;This software is supplied subject our standard software license agreement.
;A non-binding summary is as follows:
;"You may use the software in your own code at your own risk.
;" ADI inc disclaims any warranty or liability of its use".
;The full standard software license agreement is available on request and
; remains the binding agreement.

#include        <ADuC7030.inc>

; SpiCfg==========Configures SPI
; C Function prototype: int SpiCfg(int iDiv, int iFormat);
;iDiv:{0-0xff}
;iFormat:{SPI_EN|SPI_MM|SPI_PHA|SPI_POL|SPI_LSB|SPI_TIM|SPI_TXU|SPI_SRO|SPI_SSE|SPI_SOE|SPI_LBE|SPI_CTE}
; Description of Function: Configure the SPI interface.
; User interface:
;  Set iDiv to required serial clock divider
;  Set iFormat to the data format required (SPICON):
;     SPICON.0 = SPI_EN       -> Enable SPI
;     SPICON.1 = SPI_MM       -> Master mode enable bit
;     SPICON.2 = SPI_PHA      -> Serial clock phase mode bit
;     SPICON.3 = SPI_POL      -> Serial clock polarity mode bit
;     SPICON.4 = Ignored      -> Ignored
;     SPICON.5 = SPI_LSB      -> LSB first transfer enable bit
;     SPICON.6 = SPI_TIM      -> Transfer and interrupt mode
;     SPICON.7 = SPI_TXU      -> SPITX underflow mode
;     SPICON.8 = SPI_SRO      -> SPIRX overflow overwrite enable
;     SPICON.9 = SPI_SSE      -> Slave select input enable
;     SPICON.10 = SPI_SOE     -> Slave output enable
;     SPICON.11 = SPI_LBE     -> Loop back enable
;     SPICON.12 = SPI_CTE     -> Continuous transfer enable
;     SPICON.13 to SPICON.31  -> Ignored
;  Call SpiCfg.
;  Returns 1.
; Robustness:
;
                RSEG CODE
                MODULE SpiCfg
                PUBLIC SpiCfg
                CODE32

SpiCfg:  mov   r3,#0xff0000            ; r3 = Z_BASE;
         orr   r3,r3,#0xff000000
         str   r0,[r3,#Z_SPIDIV]       ; Write r0 to SPIDIV
         str   r1,[r3,#Z_SPICON]       ; Write r1 to SPICON
         ldr   r1,[r3,#Z_GP0CON]       ; Set pins to SPI mode
         mov   r1,r1, lsr #+16
         mov   r1,r1, lsl #+16
         orr   r1,r1,#0x00000011
         orr   r1,r1,#0x00001100
         str   r1,[r3,#Z_GP0CON]       ; Set pins to SPI mode
         mov   r0,#1                   ; Return 1
         bx    lr

                 ENDMOD  SpiCfg

                 END
